<?php
/**
 * @file
 * The group_mind_messages_q_a class.
 */

/**
 * Class which manage the creation of messages in the Q&A section.
 */
class group_mind_messages_q_a extends group_mind_messages {
  /****************************************************************************
   * Manage messages on all necessary drupal HOOK
   ****************************************************************************/
  /**
   * Used by group_mind_messages.module in hook_node_insert.
   *
   * @param object $node
   *   The created node.
   *
   * @see group_mind_messages.module
   */
  public function node_insert($node) {
    if ($node->type == 'answer') {
      // Not coming from transform to answer.
      if (empty($node->transform_to_answer)) {
        // If the answer is published (not filtered by antispam),
        // create the message and send an email to the question's followers.
        if ($node->status == 1) {
          $this->node_send_mail_followers('new_answer', $node, $node->field_related_question[LANGUAGE_NONE][0]['target_id'], TRUE);
        }
      }
      else {
        // We use the "update_content" here because if the moderator transform
        // to answer one of his own comment, we want to display
        // the "update_content" message.
        // If the transform someone else's comment (99% of the cases),
        // the message is not used. A mail is sent to the author and
        // a message is created on the moderator's profile.
        $this->messages_moderated('update_content', $node, FALSE);
      }
    }
    else {
      // For the question call the parent function.
      parent::node_insert($node);
    }
  }

  /**
   * Used by group_mind_messages.module in hook_node_update().
   *
   * @param object $node
   *   The updated node.
   *
   * @see group_mind_messages.module
   */
  public function node_update($node) {
    if ($node->type == 'question') {
      // The question wasn't published previously
      // (probably filtered by antispam) but now it is.
      if ($node->original->status == 0 && $node->status == 1) {
        // Create a message on the author's profile, send him an email and
        // create a message on the moderator profile (if needed).
        $this->messages_moderated('new_content', $node, TRUE);
      }
      // Or it's just an update, create the "update" message and
      // notify the followers.
      elseif ($node->status == 1) {
        $this->node_send_mail_followers('update_content', $node, $node->nid, TRUE);
      }
    }
    elseif ($node->type == 'answer') {
      // The answer wasn't published previously (probably filtered by antispam)
      // but now it is.
      if ($node->original->status == 0 && $node->status == 1) {
        // Create a message on the author's profile.
        $this->create_message('new_answer', $node);

        // Send a mail to all the followers. Will also send an email to the
        // author and create a message on the moderator's profile (if needed).
        $this->node_send_mail_followers('new_answer', $node, $node->field_related_question[LANGUAGE_NONE][0]['target_id'], TRUE);
      }
      // Or it's just an update, create the "update" message and
      // notify the followers.
      elseif ($node->status == 1) {
        $this->node_send_mail_followers('update_answer', $node, $node->field_related_question[LANGUAGE_NONE][0]['target_id'], TRUE);
      }
    }
  }

  /**
   * Used by group_mind_messages.module in hook_comment_insert().
   *
   * @param object $comment
   *   The created comment.
   *
   * @see group_mind_messages.module
   */
  public function comment_insert($comment) {
    // Not executing on transform to comment.
    if (empty($comment->transform_to_comment)) {
      // Only if the comment is published.
      // If it's not, it's probably been filtered by antispam.
      if ($comment->status == 1) {
        if ($comment->node_type == 'comment_node_question') {
          // Send mails to followers and create message on author's profile.
          $this->node_send_mail_followers('new_comment', $comment, $comment->nid, TRUE);
        }
        elseif ($comment->node_type == 'comment_node_answer') {
          // Get the associated answer to get the question nid.
          $answer = node_load($comment->nid);
          // Send mails to followers and create message on author's profile.
          $this->node_send_mail_followers('new_comment', $comment, $answer->field_related_question[LANGUAGE_NONE][0]['target_id'], TRUE);
        }
      }
    }
    else {
      // Call the parent function.
      parent::comment_insert($comment);
    }
  }

  /**
   * Used by group_mind_messages.module in hook_comment_update().
   *
   * @param object $comment
   *   The updated comment.
   *
   * @see group_mind_messages.module
   */
  public function comment_update($comment) {
    if ($comment->node_type == 'comment_node_question') {
      // The comment wasn't published previously
      // (probably filtered by antispam) but now it is.
      if ($comment->original->status == 0 && $comment->status == 1) {
        // Create a message on the author's profile.
        $this->create_message('new_comment', $comment);

        // Send a mail to the followers. Will also send an email to the author
        // and create a message on the moderator's profile if needed.
        $this->node_send_mail_followers('new_comment', $comment, $comment->nid, TRUE);
      }
      // Or it's just an update, create the "update" message.
      elseif ($comment->status == 1) {
        $this->messages_moderated('update_comment', $comment);
      }
    }
    elseif ($comment->node_type == 'comment_node_answer') {
      // The comment wasn't published previously (probably filtered by antispam)
      // but now it is.
      if ($comment->original->status == 0 && $comment->status == 1) {
        // Create a message on the author's profile.
        $this->create_message('new_comment', $comment);

        // Send a mail to the followers. Will also send an email to the author
        // and create a message on the moderator's profile if needed.
        // Get the associated answer to get the question nid.
        $answer = node_load($comment->nid);
        $this->node_send_mail_followers('new_comment', $comment, $answer->field_related_question[LANGUAGE_NONE][0]['target_id'], TRUE);
      }
      // Or it's just an update, create the "update" message.
      elseif ($comment->status == 1) {
        $this->messages_moderated('update_comment', $comment);
      }
    }
  }
}
